//
// C++ Interface: CObjectEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef COBJECTEDITDLG_H
#define COBJECTEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_objdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CObjEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CObjEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CObjEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
 
private slots:
 
protected:
    Ui::ObjEditDlg ui;    
    FolderListItem *point;
    
private:
    QWidget *myParent;
};
#endif
